@@ -3,7 +3,6 @@
   Distributed with the epidemics package for the R software.
   Licence: GPL >=2.
 
-  These functions are basic routines for simulating host populations.
 */
 #ifndef __MATVEC_H
 #include "matvec.h"
@@ -25,11 +24,16 @@
 
 
 typedef struct{
-	mat_int *transi, *transv, *nbcommon;
+	mat_int *mutation1, *mutation2, *nbcommon;
 	int n;
 } dna_dist;
 
 
+typedef struct{
+	mat_double *dist;
+	int n;
+} spatial_dist;
+
 
 /*
    ====================
@@ -37,7 +41,9 @@ typedef struct{
    ====================
 */
 
-dna_dist * create_dna_dist(int n);
+dna_dist * alloc_dna_dist(int n);
+
+spatial_dist * alloc_spatial_dist(int n);
 
 
 
@@ -49,6 +55,8 @@ dna_dist * create_dna_dist(int n);
 
 void free_dna_dist(dna_dist * in);
 
+void free_spatial_dist(spatial_dist * in);
+
 
 
 
@@ -61,13 +69,13 @@ void free_dna_dist(dna_dist * in);
 
 bool is_atgc(char in);
 
-int get_transi(dna_dist * in, int i, int j);
+int get_mutation1(dna_dist * in, int i, int j);
 
-int get_transv(dna_dist * in, int i, int j);
+int get_mutation2(dna_dist * in, int i, int j);
 
 int get_nbcommon(dna_dist * in, int i, int j);
 
-
+double get_spatial_dist(spatial_dist * in, int i, int j);
 
 
 
@@ -79,7 +87,11 @@ int get_nbcommon(dna_dist * in, int i, int j);
 
 void print_dna_dist(dna_dist *in);
 
-dna_dist * compute_dna_distances(list_dnaseq *in);
+void print_spatial_dist(spatial_dist *in);
+
+dna_dist * compute_dna_distances(list_dnaseq *in, int mut_model);
+
+spatial_dist * doublevec2spatial_dist(double *in, int *n);
 
 
 #endif
