@@ -12,12 +12,12 @@ double gsl_ran_exponential_pdf_fixed(double x, double mu);
 
 double logprior_pi(param *par);
 
+double logprior_phi(param *par);
+
 double logprior_spa1(param *par);
 
 double logprior_spa2(param *par);
 
-/* double logprior_phi(param *par); */
-
 double logprior_mu1(param *par);
 
 double logprior_gamma(param *par);
